---
title: "{{project_title}}"
author: "{{author}}"
bibliography: [data/records.bib,data/non_sample_references.bib]
figPrefix: "Figure"
tblPrefix: "Table"
csl: "https://raw.githubusercontent.com/citation-style-language/styles/master/apa.csl"
---

# Abstract

**Keywords**: keyword 1; keyword 2; {{review_type}}.

# Introduction

# Methodology

Data was managed with CoLRev version {{colrev_version}} [@WagnerPrester2022].

## Search

## Screen

## Data extraction

## Risk of bias assessment

## Analysis

# Synthesis

# Conclusion

# Appendix

<!-- NEW_RECORD_SOURCE -->

# References
